@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20120131';
+our $VERSION = '0.20120229';
 
-# Table last modified: 2012-01-31
+# Table last modified: 2012-02-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -104,7 +104,7 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
-    '101' => '(?:8(?:3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|4(?:7[05-7]|8[13]|0[57-9]|3[0379]|4[13-9]|6[04-9]|5[0-46-9]|2[125]|1[0-25689])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
+    '101' => '(?:8(?:4(?:7[05-7]|8[13]|0[57-9]|3[0379]|2[1-5]|4[13-9]|6[04-9]|5[0-46-9]|1[0-25689])|3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|6(?:8[28]|0[5-79]|1[0-379]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|7[0237]|5[035-7]|6[248]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[125689])|79[58]))',
     '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-256]|3[0-57-9]|1[0-79]|8[01467]|5[016]|4[3489])|2(?:3\d|0[1-6]|1[0-2478]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|5(?:0[1-367]|4[2358]|8[4-689]|2[0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|1[0-2])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|8[0469]|5[0-36]|3[1269]|4[014])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:3[013-689]|4[03-578]|1[015689]|8[168]|0[1-8]|[67][068]|5[0156]|2[0-59])|5(?:1[028]|4[0468]|3[03589]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
@@ -126,11 +126,11 @@ our %ZIP_TABLE = (
     '124' => '(?:8(?:5(?:77|6[06]|1[018]|3[3589]|0[1-39]|8[58]|5[05]|2[024])|070))',
     '125' => '(?:8(?:5(?:55|88|1[1-57]|0[3-8]|2[026])|60[12]))',
     '130' => '(?:8(?:5(?:6[5-7]|8[03-58]|7[057]|3[013-589]|4[358]|5[4-8]|0[13-9]|1[0-8]|2[0258])|6(?:25|86|0[1-589]|7[17]|4[02]|3[67]|5[05]|6[068]|1[15])|7(?:[12]0|0[16])))',
-    '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-9])|711))',
+    '131' => '(?:8(?:5(?:40|65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[13-9])|634|711))',
     '132' => '(?:8(?:5(?:33|85|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:3[029]|1[15])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:3[0-35]|5\d|7[03-57-9]|8[125-7]|0[1458]|4[08]|2[1-358]|1[0-478]|6[035-8])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|11[0-4]|080))',
+    '135' => '(?:8(?:5(?:5\d|3[0-358]|7[03-57-9]|8[125-7]|0[1458]|4[08]|2[1-358]|1[0-478]|6[035-8])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|11[0-4]|080))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|6[07]|5[05]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|3[013689]|6[0367]|2[013569]|0[125-8]|5[0-28]|1[1256])|6(?:7[02578]|4[04]|0[17]|6[0168]|1[13-79]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
@@ -140,7 +140,7 @@ our %ZIP_TABLE = (
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[014]|6[01])))',
     '145' => '(?:85(?:[23]3|01|58|66|1[15]))',
     '146' => '(?:8(?:5(?:[03]1|22|67|8[058]|7[67]|1[0-2]|5[15]|4[034])|6(?:[03]1|10|2[03]|5[056]|7[78]|6[68])))',
-    '150' => '(?:8(?:5(?:45|3[03]|0[23578]|8[5-7]|2[25]|1[124-7]|6[379]|5[05]|7[57])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:5(?:45|3[03]|8[5-7]|2[25]|6[379]|5[05]|7[57]|1[0-24-7]|0[2357-9])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|5[24589]|7[0-46-8]|9[01]|0[2-579])|6(?:00|7[1-7])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[01458]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
@@ -160,7 +160,7 @@ our %ZIP_TABLE = (
     '168' => '(?:8(?:5(?:[67]0|85|3[03]|5[058]|0[1-468]|2[05]|1[0-2])|6(?:01|26|[18][16])|081))',
     '169' => '(?:8(?:5(?:6[018]|2[0-25-7]|8[0568]|4[013]|7[07]|3[0135]|0[37-9]|1[015-7]|5[01568])|6(?:2[04]|5[056]|7[78]|0[1358]|1[0-36]|6[1468]|4[0458]|3[179])|0(?:50|77|1[12])|7(?:[01]1|22)|915))',
     '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|7[067]|5[015-9]|6[0156]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|12|0[25]|[35][35])|0(?:55|73)|5(?:51|85))|6080))',
-    '171' => '(?:85(?:8[26]|3[19]|7[027]|5[023578]|4[045]|2[0-35-8]|1[0-2468]|6[0189]|0[1-37-9]))',
+    '171' => '(?:85(?:3[19]|7[027]|5[023578]|4[045]|2[0-35-8]|8[268]|1[0-2468]|6[0189]|0[1-37-9]))',
     '173' => '(?:8(?:5(?:[06]1|30|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|66|3[29]|1[01]|0[1256])|710))',
     '174' => '(?:8(?:5(?:30|88|5[058]|6[07]|2[0146]|0[15])|6(?:01|12|46|3[369]|8[068])|7(?:[01]1|3[079]|4[0134])|860|903))',
     '175' => '(?:85(?:88|7[17]))',
@@ -233,7 +233,7 @@ our %ZIP_TABLE = (
     '251' => '(?:8(?:5(?:40|2[02]|5[0158]|1[0135]|6[067]|8[18]|3[014]|0[125])|601))',
     '252' => '(?:(?:5(?:2(?:01|33|77|8[0568]|5[258]|1[01]|2[125]|9[2-578])|1(?:[56]2|8[128]|7[27]|9[126]))|0(?:3(?:7[03-57]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|[47]0|11|85|3[89]|6[67]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:[03]1|10|22|43|67|7[17]|5[058]|8[58])|686)|019[235-8]))',
-    '254' => '(?:8(?:5(?:43|55|3[23]|8[58]|0[12])|6(?:01|86|1[024])))',
+    '254' => '(?:8(?:5(?:43|55|8[58]|0[12]|3[023])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
     '256' => '(?:8510)',
     '257' => '(?:8(?:5(?:11|33|55|66|2[23]|0[12]|8[4-68])|686))',
@@ -415,7 +415,7 @@ our %ZIP_TABLE = (
     '441' => '(?:(?:8(?:5(?:6[06]|2[025]|5[058]|7[07]|8[08]|0[1-37]|1[0-2579]|4[035]|3[039])|6[68]6)|0(?:19[3-5]|29[25]|39[23])|3(?:19[2-6]|492|695)|1(?:29[2-5]|[346]92)))',
     '442' => '(?:8(?:5(?:20|58|3[0-358]|0[1-35-79]|6[169]|1[0-35-8]|8[0-25-8]|7[35-7]|9[01]|4[013-6])|60[1-3]))',
     '443' => '(?:(?:8(?:5(?:55|88)|6[01]1)|019[2-4]))',
-    '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-267]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[2-4]|89[23])))',
+    '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|1[0-25-7]|8[1568]|2[02]|4[235]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[2-4]|89[23])))',
     '445' => '(?:8(?:5(?:85|1[01]|0[1-35])|60[12]))',
     '446' => '(?:8(?:5(?:40|1[12478]|3[35]|0[1-8]|[58][58]|2[02-6])|6(?:35|41|86|0[12])))',
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
@@ -424,7 +424,7 @@ our %ZIP_TABLE = (
     '450' => '(?:(?:8(?:5(?:40|3[0238]|2[0-3]|6[17]|1[05]|7[57]|8[035]|0[125])|6(?:[48]0|01|77|2[06]|1[148]|5[01])|7(?:11|30|65))|6133))',
     '451' => '(?:8(?:5(?:[14]1|85|[25][015]|6[0158]|0[1-38]|7[0157])|6(?:50|88)|701))',
     '452' => '(?:8(?:5(?:21|44|70|0[1-3]|6[1-79])|60[1-4]))',
-    '453' => '(?:8(?:5(?:[56]5|40|77|8[015]|2[12]|0[15]|3[039]|1[0-28])|6(?:[01]1|62|86)|7(?:65|77)))',
+    '453' => '(?:8(?:5(?:[56]5|40|77|8[015]|2[12]|0[15]|3[039]|1[0-28])|6(?:[01]1|62|86)|7(?:58|65|77)))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
     '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[1458]5|21|30|0[15])))',
     '456' => '(?:8(?:5(?:23|30|6[07]|1[16]|8[0578]|0[12]|5[56])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
@@ -510,7 +510,7 @@ our %ZIP_TABLE = (
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
     '540' => '(?:(?:8(?:5(?:66|2[1267]|5[01589]|0[158]|3[03-5]|7[01578]|4[014]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
-    '541' => '(?:(?:85(?:5[01346-9]|2[013-689]|3[0457-9]|4[0-35-9]|1[124-9]|6[3568]|8[13-79]|7[15-9]|0[1-689])|6666))',
+    '541' => '(?:(?:85(?:5[01346-9]|2[013-689]|3[0457-9]|4[0-35-9]|1[124-9]|6[3568]|7[15-9]|8[14-79]|0[1-689])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|[58][58]|0[12])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:01|55)|666))',
@@ -518,7 +518,7 @@ our %ZIP_TABLE = (
     '546' => '(?:8501)',
     '547' => '(?:85(?:01|80|1[04]))',
     '549' => '(?:85(?:01|85))',
-    '550' => '(?:8(?:5(?:38|6[67]|2[27]|8[05]|7[0578]|5[0258]|0[1-35])|6(?:59|60)))',
+    '550' => '(?:8(?:5(?:10|38|6[67]|2[27]|8[05]|7[0578]|5[0258]|0[1-35])|6(?:59|60)))',
     '551' => '(?:85[05]1)',
     '552' => '(?:85(?:01|10))',
     '553' => '(?:8(?:5(?:01|67|1[1-3]|5[03]|8[58])|739))',
@@ -542,7 +542,7 @@ our %ZIP_TABLE = (
     '572' => '(?:85(?:40|67|8[01589]|2[28]|3[013]|7[02]|5[0158]|0[1578]|1[01]))',
     '573' => '(?:(?:8(?:5(?:11|34|73)|666)|10(?:[34]0|01)|019[25]))',
     '574' => '(?:85(?:01|55|3[04]))',
-    '575' => '(?:85(?:[01]1|[58][58]))',
+    '575' => '(?:85(?:[01]1|30|[58][58]))',
     '576' => '(?:8501)',
     '577' => '(?:8(?:5(?:11|40|3[37]|0[2359]|5[01458]|8[1258]|6[067]|7[57]|2[0-2])|611))',
     '578' => '(?:85(?:22|55|77|8[58]|0[12]|1[15]))',
@@ -711,7 +711,7 @@ our %ZIP_TABLE = (
     '752' => '(?:8(?:5(?:01|85|5[58]|1[01])|60[19]))',
     '753' => '(?:(?:8(?:5(?:40|88|7[07]|5[58]|1[0-57-9]|0[1-46-9]|3[0-8]|2[0-25689])|65[034])|029[23]))',
     '754' => '(?:(?:8(?:5(?:[358]5|[01]1|22)|6(?:01|1[01]))|1(?:19[23]|292)|0291))',
-    '755' => '(?:(?:8(?:5(?:22|43|77|8[058]|6[067]|1[01]|5[0457]|0[125])|6(?:33|42|0[19]|2[25]|1[01]))|019[25]))',
+    '755' => '(?:(?:8(?:5(?:22|43|8[058]|6[067]|1[01]|5[0457]|0[125])|6(?:33|42|0[19]|2[25]|1[01]))|019[25]))',
     '756' => '(?:8(?:5(?:85|0[12])|60[12]))',
     '757' => '(?:(?:8(?:5(?:11|85)|6(?:34|86))|029[28]))',
     '758' => '(?:8(?:6(?:15|86|4[58])|5(?:[58]5|70)))',
@@ -758,8 +758,8 @@ our %ZIP_TABLE = (
     '799' => '(?:(?:1(?:5(?:8[128]|9[2-68])|39[2-5]|198|692)|2(?:49[2356]|29[2-4]|19[25]|39[23]|69[26])|0(?:19[2-7]|49[235-8])|3(?:19[2-6]|79[23]|292)))',
     '800' => '(?:(?:0(?:2(?:9[3-8]|8[1-48])|39[2-6])|8(?:5(?:10|85|5[05])|6(?:11|86|0[13]))))',
     '801' => '(?:8(?:5(?:85|5[05]|0[237]|1[01])|601))',
-    '802' => '(?:8(?:5(?:8[015]|3[34]|2[124]|1[0-25]|6[067]|[45][05]|0[18]|7[017])|6(?:42|51|77|86|0[14])|701))',
-    '803' => '(?:8(?:5(?:20|43|3[0-35]|6[17]|5[058]|8[068]|1[0-357]|0[1458])|6(?:02|30|86|6[06])|787))',
+    '802' => '(?:8(?:5(?:8[015]|3[34]|5[058]|2[124]|1[0-25]|6[067]|4[05]|0[18]|7[017])|6(?:42|51|77|86|0[14])|701))',
+    '803' => '(?:8(?:5(?:20|43|3[0-35]|1[0-37]|6[17]|5[058]|8[068]|0[1458])|6(?:02|30|86|6[06])|787))',
     '804' => '(?:8(?:5(?:[12]0|77|88|0[135]|3[89]|5[058])|601))',
     '805' => '(?:8(?:5(?:[58]5|3[013-689]|2[0178]|0[1357-9]|1[02-468])|6(?:06|25)))',
     '806' => '(?:8(?:5(?:67|70|4[03]|0[19]|5[58]|1[01]|8[56])|6(?:[68]6|12|79)))',
@@ -776,7 +776,7 @@ our %ZIP_TABLE = (
     '817' => '(?:(?:1(?:[26]92|797)|85(?:20|1[07])))',
     '818' => '(?:(?:8(?:5(?:34|55|67|0[1-3]|1[69]|7[178]|4[09]|8[58])|6(?:42|86|6[68]))|019[2-578]))',
     '819' => '(?:(?:85(?:11|33|85|5[0-258]|0[124])|1(?:19[235]|[36]92)|0(?:39[25]|192)))',
-    '820' => '(?:(?:8(?:5(?:[24]0|33|55|1[02367]|0[125-8])|60[1-357])|0(?:[2357]92|69[36]|193)|119[23]))',
+    '820' => '(?:(?:8(?:5(?:[24]0|33|55|1[02367]|0[125-8])|60[1-357])|0(?:[2357]92|69[36])|119[23]))',
     '821' => '(?:8501)',
     '822' => '(?:(?:1(?:29[236]|19[23]|492)|8(?:5(?:[58]5|01)|666)))',
     '823' => '(?:8555)',
@@ -816,9 +816,9 @@ our %ZIP_TABLE = (
     '857' => '(?:(?:8(?:5(?:33|58|66|0[1-38]|8[58]|7[57]|1[01])|6(?:[68]6|11))|2(?:49[24]|392)|4(?:495|592)|119[23578]|0[134]92))',
     '858' => '(?:85(?:01|55|8[0589]))',
     '859' => '(?:(?:3(?:79[2378]|29[238]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
-    '860' => '(?:8(?:5(?:4[1357]|3[0149]|7[057]|8[04-8]|6[5-8]|0[1347-9]|5[0-24-8]|2[0-578]|1[0-8])|6(?:55|2[245]|8[168]|1[159]|0[1-68]|6[08])|79[57]))',
-    '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|1(?:19[23578]|39[24]|295)|4(?:19[23578]|[34]92|696)|3(?:19[24-6]|29[56]|592)|2(?:29[235-7]|[14]92)|85(?:01|14|38|2[089])|5(?:49[2-5]|59[28])|6[13]95|7292))',
-    '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[35]|0[139]|1[0-2]|8[08]|5[125])|7(?:20|44|1[06]|9[34]|0[12])|5(?:[127]0|0[258])))',
+    '860' => '(?:8(?:5(?:4[1357]|3[0149]|7[057]|8[04-8]|6[5-8]|0[1347-9]|5[0-24-8]|2[0-578]|1[0-8])|6(?:55|2[245]|1[1589]|8[168]|0[1-68]|6[08])|79[57]))',
+    '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|4(?:1(?:89|9[235-8])|[34]92|696)|1(?:19[23578]|39[24]|295)|3(?:19[24-6]|29[56]|592)|5(?:49[2-5]|59[28]|292)|2(?:29[235-7]|[14]92)|85(?:01|14|38|2[089])|6[13]95|7292))',
+    '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[35]|0[139]|1[0-2]|8[08]|5[125])|7(?:20|44|1[06]|9[34]|0[12])|5(?:[127]0|55|0[258])))',
     '863' => '(?:(?:8(?:6(?:31|86)|5[58]5)|2(?:292|895)|1992))',
     '864' => '(?:8(?:6(?:11|86)|501))',
     '865' => '(?:(?:85(?:[01]1|33|77|5[05])|019[23]))',
